// src/components/Button/Button.tsx
import React from "react";

// src/components/Button/Button.styles.ts
import styled from "styled-components";

// src/theme/mudah.ts
var neutrals = {
  black: "#222222",
  darkgray1: "",
  darkgray2: "",
  darkgray3: "#777777",
  darkgray4: "",
  gray1: "#9B9B9B",
  gray2: "#CACACA",
  gray3: "#E8E8E8",
  gray4: "#F4F4F4",
  gray5: "#F8F8F8",
  white: "#FFFFFF"
};
var px = (v) => `${v}px`;
var breakpoints = ["576px", "768px", "992px", "1200px", "1400px"];
var mediaQueries = {
  tablet: `screen and (min-width: ${breakpoints[1]})`,
  desktop: `screen and (min-width: ${breakpoints[2]})`
};
var iconSizeScale = [16, 20, 22, 24, 32, 40, 50, 75, 100, 105].map(px);
var sizes = {
  vW: "100vw",
  vH: "100vh",
  quarter: "25%",
  third: "33.33%",
  half: "50%",
  twoThird: "66.66%",
  threeQuarter: "75%",
  full: "100%",
  icons: iconSizeScale,
  [1 / 4]: "25%",
  [1 / 3]: "33.33%",
  [1 / 2]: "50%",
  [2 / 3]: "66.66%",
  [3 / 4]: "75%",
  1: "100%"
};
var fonts = {
  body: "-apple-system, BlinkMacSystemFont, Open Sans, Roboto, sans-serif",
  heading: "inherit",
  monospace: "SFMono-Regular, Consolas, Liberation Mono, Menlo, monospace"
};
var inputHeights = {
  sm: "36px",
  md: "56px",
  xs: "176px"
};
var fontWeights = {
  regular: 400,
  bold: 700,
  body: 400,
  heading: 700,
  normal: 400
};
var primarys = {
  primary50: "#ffebef",
  primary100: "#FFCDD4",
  primary200: "#F7999D",
  primary300: "#F07176",
  primary400: "#FD4C53",
  primary500: "#FF3638",
  primary600: "#F42B38",
  primary700: "#E21E30",
  primary800: "#D5132A",
  primary900: "#9E0017"
};
var secondarys = {
  secondary50: "#DDEFFD",
  secondary100: "#BBDEFB",
  secondary200: "#90CAF9",
  secondary300: "#64B5F6",
  secondary400: "#42A5F5",
  secondary500: "#2196F3",
  secondary600: "#1E88E5",
  secondary700: "#1976D2",
  secondary800: "#1565C0",
  secondary900: "#0D47A1"
};
var greens = {
  green50: "#E5F4E9",
  green100: "#C0E5C9",
  green200: "#97D3A8",
  green300: "#6BC385",
  green400: "#47B76C",
  green500: "#17AA52",
  green600: "#0a9b49",
  green700: "#00893D",
  green800: "#007832",
  green900: "#00591F"
};
var yellows = {
  yellow50: "#FFF7E1",
  yellow100: "#FEEAB4",
  yellow200: "#FEDD84",
  yellow300: "#FDD153",
  yellow400: "#FCC630",
  yellow500: "#FBBD1C",
  yellow600: "#FBAF17",
  yellow700: "#FA9D16",
  yellow800: "#FA8C15",
  yellow900: "#F86D13"
};
var grays = {
  gray50: "#FAFAFA",
  gray100: "#F5F5F5",
  gray200: "#EEEEEE",
  gray300: "#E0E0E0",
  gray400: "#BDBDBD",
  gray500: "#9E9E9E",
  gray600: "#757575",
  gray700: "#616161",
  gray800: "#424242",
  gray900: "#212121"
};
var surfaces = {
  surface1: "#ffebef",
  surface2: "#E1F6FD",
  surface3: "#E5F4E9",
  surface25: "#FFFFFF",
  surface100: "#F5F5F5",
  surface300: "#E0E0E0",
  surface500: "#9E9E9E",
  surface700: "#616161",
  surface900: "#212121"
};
var error = {
  error50: "#ffebef",
  error900: "#C7001D"
};
var warning = {
  warning50: "#FFF7E1",
  warning800: "#FA8C15"
};
var success = {
  success50: "#E5F4E9",
  success700: "#00893D"
};
var texts = {
  text038: "#00000061",
  text060: "#00000099",
  text087: "#000000DE",
  text025: "#FFFFFF",
  text600: "#1E88E5",
  text900: "#9E0017"
};
var buttons = {
  buttonRed: primarys.primary700,
  buttonBlue: secondarys.secondary600
};
var semantics = {
  white: "#FFFFFF",
  black: "#000000",
  backgroundIOS: "#34C759",
  grayIOS: "rgba(242, 242, 242, 0.8)",
  text: texts.text087,
  textLighter: texts.text060,
  link: texts.text600,
  primary: primarys.primary700,
  secondary: secondarys.secondary600,
  green: greens.green600,
  yellow: yellows.yellow600,
  border: grays.gray500,
  background: grays.gray300
};
var colors = {
  ...primarys,
  ...secondarys,
  ...neutrals,
  ...greens,
  ...yellows,
  ...grays,
  ...surfaces,
  ...error,
  ...success,
  ...warning,
  ...texts,
  ...semantics,
  ...yellows,
  ...greens,
  ...buttons
};
var radii = {
  none: 0,
  xs: "2px",
  sm: "4px",
  md: "8px",
  lg: "14px",
  xl: "20px",
  pill: "9999px",
  circle: "100%"
};
var zIndices = {
  initial: "auto",
  neutral: 0,
  up: 1,
  down: -1,
  notification: 1900,
  tooltip: 1800,
  modal: 1700,
  dropdown: 1600
};
var theme = Object.freeze({
  breakpoints: {
    ...breakpoints,
    sm: "576px",
    md: "768px",
    lg: "992px",
    xl: "1200px",
    xxl: "1400px"
  },
  mediaQueries,
  sizes,
  fonts,
  fontWeights,
  colors: {
    ...colors,
    line: "#ddd"
  },
  radii,
  inputHeights,
  texts,
  zIndices
});
var mudah_default = theme;

// src/theme/index.ts
var theme_default = mudah_default;

// src/components/Button/Button.styles.ts
var {
  colors: colors2,
  fonts: fonts2
} = theme_default;
var ButtonStyle = styled.button`
  cursor: pointer;
  display: inline-flex;
  align-items: center;
  border: none;
  text-decoration: none;
  padding: 0.5rem 1rem;
  border-radius: 0.5rem;
  font-size: 0.88rem;
  line-height: 1.25rem;
  font-weight: 600;
  font-family: ${fonts2.body};
  height: fit-content;
  user-select: none;

 &.pri {
    color: ${colors2.primary};
    background-color: ${colors2.primary};
    border-color: ${colors2.primary};
    &:hover {
      color: ${colors2.primary500};
      background-color: ${colors2.primary500};
      border-color: ${colors2.primary500};
    }
    &:active {
      color: ${colors2.primary900};
      background-color: ${colors2.primary900};
      border-color: ${colors2.primary900};
    }
  }

  &.sec {
    color: ${colors2.secondary};
    background-color: ${colors2.secondary};
    border-color: ${colors2.secondary};
    &:hover {
      color: ${colors2.secondary400};
      background-color: ${colors2.secondary400};
      border-color: ${colors2.secondary400};
    }
    &:active {
      color: ${colors2.secondary700};
      background-color: ${colors2.secondary700};
      border-color: ${colors2.secondary700};
    }
  }

  &.net {
    color: ${colors2.gray600};
    background-color: ${colors2.gray600};
    border-color: ${colors2.gray600};
    &:hover {
      color: ${colors2.gray500};
      background-color: ${colors2.gray500};
      border-color: ${colors2.gray500};
    }
    &:active {
      color: ${colors2.gray800};
      background-color: ${colors2.gray800};
      border-color: ${colors2.gray800};
    }
  }

  &.hi {
    color:  ${colors2.white};
    box-shadow: 0 2px 6px rgba(0, 0, 0, 0.1);
    &:hover {
      color:  ${colors2.white};
    }
    &:active {
      color:  ${colors2.white};
    }
  }

  &.med {
    border-style: solid;
    border-width: 1px;
    background: transparent;
    &:hover {
      background: transparent;
    }
    &:active {
      background: transparent;
    }
  }

  &.low {
    background-color: transparent;
    box-shadow: none;
    &:hover {
      background-color: transparent;
    }
    &:active {
      background-color: transparent;
    }
  }

  &.hyperlink {
    cursor: pointer;
    display: inline-flex;
    align-items: center;
    border: none;
    font-size: 1rem;
    line-height: 1.5rem;
    padding: 0;
    font-weight: 400;
    background-color: transparent;
    box-shadow: none;
    color: ${colors2.secondary};
    text-decoration: underline;

    &:hover {
      color: ${colors2.secondary400};
      background-color: transparent;
      text-decoration: underline;
    }
    &:active {
      color: ${colors2.secondary700};
      background-color: transparent;
      text-decoration: underline;
    }
  }

  /* Inner icons */
  svg {
    margin-right: 0.66em;
    font-size: 1.1rem;
  }

  &:focus {
    outline: none;
  }

  &.disabled,
  &:disabled,
  &[disabled] {
    opacity: 0.4;
    cursor: default;
    pointer-events: none;
  }
`;
var Button_styles_default = ButtonStyle;

// src/components/Button/Button.tsx
import { jsx } from "react/jsx-runtime";
var STYLES = [
  "btn-pri-hi",
  "btn-sec-hi",
  "btn-net-hi",
  "btn-pri-med",
  "btn-sec-med",
  "btn-net-med",
  "btn-pri-low",
  "btn-sec-low",
  "btn-net-low",
  "hyperlink"
];
var Button = React.forwardRef(
  ({
    id,
    disabled = false,
    styles,
    children,
    className,
    ...props
  }, ref) => {
    const [color, setColor] = React.useState("pri");
    const [type, setType] = React.useState("hi");
    const classname = styles?.split(" ").reverse().find((value) => STYLES.includes(value));
    React.useEffect(() => {
      if (classname) {
        if (classname !== "hyperlink") {
          setColor(classname.split("-")?.[1]);
          setType(classname.split("-")?.[2]);
        } else {
          setColor("hyperlink");
        }
      }
    }, [classname]);
    const attrs = {
      ref,
      ...props
    };
    return /* @__PURE__ */ jsx(Button_styles_default, {
      ...attrs,
      className: `btn ${color} ${type} ${disabled && "disabled"} ${className} ${styles}`,
      children
    });
  }
);
